@@ -411,7 +411,7 @@ class ReturnSeries(TimeSeries):
 
         return result
 
-    def calc_ann_vol(
+    def get_ann_vol(
         self,
         freq: Optional[str] = "M",
         include_bm: Optional[bool] = True,
@@ -617,7 +617,7 @@ class ReturnSeries(TimeSeries):
                 ann_excess_ret = exccess_series.get_ann_ret(
                     method=compound_method, include_bm=False
                 )["value"][0]
-                ann_series_vol = series.calc_ann_vol(
+                ann_series_vol = series.get_ann_vol(
                     freq=freq, compound_method=compound_method, include_bm=False
                 )["value"][0]
                 ratio = ann_excess_ret / ann_series_vol
